<?php

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Component\Utility\Html;
use Drupal\Core\Url;

/**
 * Implements hook_token_info().
 */
function notice_killer_token_info() {
  $info = [];

  $info['types']['notice_killer_log_entry'] = [
    'name' => t('Notice killer log entry'),
    'description' => t('Log entries created by the notice killer module'),
    'needs-data' => 'notice_killer_log_entry',
  ];

  $info['tokens']['notice_killer_log_entry']['type'] = [
    'name' => t('Type'),
    'description' => t('The type of log message'),
  ];

  $info['tokens']['notice_killer_log_entry']['message'] = [
    'name' => t('Message'),
    'description' => t('The log message'),
  ];

  $info['tokens']['notice_killer_log_entry']['severity'] = [
    'name' => t('Severity'),
    'description' => t('Severity'),
  ];

  $info['tokens']['notice_killer_log_entry']['request-uri'] = [
    'name' => t('Request URI'),
    'description' => t('Request URI where the log message occurred.'),
  ];

  $info['tokens']['notice_killer_log_entry']['view-url'] = [
    'name' => t('View URL'),
    'description' => t('The URL to view more information about this event.'),
  ];

  $info['tokens']['notice_killer_log_entry']['logged-time'] = [
    'name' => t('Logged time'),
    'description' => t('The time and date the event was logged.'),
    'type' => 'date',
  ];

  return $info;
}

/**
 * Implements hook_tokens().
 */
function notice_killer_tokens($type, $tokens, array $data = [], array $options = []) {
  $replacements = [];

  $url_options = ['absolute' => TRUE];

  $sanitize = !empty($options['sanitize']);

  if ($type == 'notice_killer_log_entry' && !empty($data['notice_killer_log_entry'])) {
    $log_entry = $data['notice_killer_log_entry'];
    foreach ($tokens as $name => $original) {
      switch ($name) {
        case 'type':
          $replacements[$original] = $sanitize ? Html::escape($log_entry['type']) : $log_entry['type'];
          break;

        case 'message':
          $replacements[$original] = $sanitize ? Html::escape(new FormattableMarkup($log_entry['message'], $log_entry['variables'])) : new FormattableMarkup($log_entry['message'], $log_entry['variables']);
          break;

        case 'severity':
          $severity_levels = notice_killer_severity_levels();
          $replacements[$original] = $sanitize ? Html::escape($severity_levels[$log_entry['severity']]) : $severity_levels[$log_entry['severity']];
          break;

        case 'request-uri':
          $replacements[$original] = $sanitize ? Html::escape($log_entry['request_uri']) : $log_entry['request_uri'];
          break;

        case 'view-url':
          $replacements[$original] = Url::fromRoute('notice_killer.event', $url_options + ['wid' => $log_entry['wid']]);
          break;

        case 'logged-time':
          $replacements[$original] = date_format($log_entry['timestamp'], 'medium');
          break;
      }
    }

    $created_tokens = \Drupal::token()->findWithPrefix($tokens, 'logged-time');
    if ($created_tokens) {
      // @TODO Pass in bubbleable metadata.
      $replacements += \Drupal::token()->generate('date', $created_tokens, ['date' => $log_entry['timestamp']], $options);
    }
  }
  return $replacements;
}
