<?php

namespace Drupal\notice_killer\Form;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Url;

class ConfirmDeleteSingle extends ConfirmFormBase {

  /**
   * Event wid to delete.
   * @var int
   */
  protected $wid = NULL;

  /**
   * Build the confirmation form.
   *
   * @param array $form
   *   Form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Form state.
   * @return array
   */
  public function buildForm(array $form, FormStateInterface $form_state, $wid = NULL) {
    $this->wid = $wid;

    return parent::buildForm($form, $form_state);
  }

  /**
   * @inheritDoc
   */
  public function getQuestion() {
    return t('Delete this notice?');
  }

  /**
   * @inheritDoc
   */
  public function getCancelUrl() {
    return \Drupal::urlGenerator()->generateFromRoute('notice_killer.overview');
  }

  /**
   * @inheritDoc
   */
  public function getFormId() {
    return 'notice_killer_confirm_delete_single';
  }

  /**
   * @inheritDoc
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Set up our batch update and run it.
    $batch = [
      'title' => t('Clear notice logs'),
      'operations' => [
        ['notice_killer_event_delete', [$this->wid]],
      ],
      'progress_message' => 'Deleting notice data',
      'finished' => 'Drupal\notice_killer\Form\ConfirmDeleteSingle::batchFinished',
      'batch_redirect' => Url::fromRoute('notice_killer.overview')->toString(),
      'file' => \Drupal::service('extension.list.module')->getPath('notice_killer') . '/notice_killer.admin.inc',
    ];
    batch_set($batch);

    // Return to the edit form once complete.
    $form_state->setRedirect('notice_killer.overview');
  }

  /**
   * Checks access for this product + user.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account) {
    // Admins only!
    if ($account->hasPermission('access site reports')) {
      return AccessResult::allowed();
    }
    return AccessResult::forbidden();
  }

  /**
   * Batch finished callback.
   */
  public static function batchFinished($success) {
    if (!$success) {
      \Drupal::service('messenger')->addMessage(t('An error occurred while deleting the notice'));
    }
  }

}
