<?php

namespace Drupal\notice_killer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class SettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'notice_killer.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'notice_killer_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['notice_killer_backtrace'] = [
      '#type' => 'radios',
      '#title' => t('Capture backtrace of notices/warnings'),
      '#description' => t('Additionally capture a backtrace when the notice or warning is first observed. NOTE: this can capture user sensitive data and should be used carefully.'),
      '#default_value' => $config->get('notice_killer_backtrace'),
      '#options' => [
        'none' => t('Do not capture stacktraces.'),
        'function' => t('Capture stacktraces of functions, but do not capture arguments.'),
        'argument' => t('Capture stacktraces and include arguments. WARNING: security risk'),
      ],
    ];

    $options = [
      strtotime('1 hour', 0) => t('1 hour'),
      strtotime('1 day', 0) => t('1 day'),
      strtotime('1 week', 0) => t('1 week'),
      strtotime('2 weeks', 0) => t('2 weeks'),
      strtotime('4 weeks', 0) => t('4 weeks'),
      strtotime('1 year', 0) => t('1 year'),
    ];

    $form['notice_killer_expiry'] = [
      '#type' => 'select',
      '#title' => t('Remove expired notices'),
      '#description' => t('Delete logs of recorded notices after they have not been seen for the specified amount of time.'),
      '#options' => ['' => t('Never')] + $options,
      '#default_value' => $config->get('notice_killer_expiry'),
    ];

    $form['notice_killer_prevent_dblog_notices'] = [
      '#type' => 'checkbox',
      '#title' => t('Prevent the dblog module from logging PHP notices and warnings.'),
      '#default_value' => $config->get('notice_killer_prevent_dblog_notices'),
      '#access' => \Drupal::moduleHandler()->moduleExists('dblog'),
      '#description' => t('If checked then PHP notices and warnings will ONLY be logged by notice killer and not appear in the the normal recent log messages.'),
    ];

    $form['notice_killer_prevent_syslog_notices'] = [
      '#type' => 'checkbox',
      '#title' => t('Prevent the syslog module from logging PHP notices and warnings.'),
      '#default_value' => $config->get('notice_killer_prevent_syslog_notices'),
      '#access' => \Drupal::moduleHandler()->moduleExists('syslog'),
      '#description' => t('If checked then PHP notices and warnings will ONLY be logged by notice killer and not appear in the the normal recent log messages.'),
    ];

    $form['notice_killer_ignore_line_numbers'] = [
      '#type' => 'checkbox',
      '#title' => t('Ignore line numbers of notices when comparing with existing logs.'),
      '#default_value' => $config->get('notice_killer_ignore_line_numbers'),
    ];

    $form['notice_killer_ignore_file_location'] = [
      '#type' => 'checkbox',
      '#title' => t('Ignore file locations in notices when comparing with existing logs.'),
      '#default_value' => $config->get('notice_killer_ignore_file_location'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve the configuration.
    $this->config(static::SETTINGS)
      ->set('notice_killer_backtrace', $form_state->getValue('notice_killer_backtrace'))
      ->set('notice_killer_expiry', $form_state->getValue('notice_killer_expiry'))
      ->set('notice_killer_prevent_dblog_notices', $form_state->getValue('notice_killer_prevent_dblog_notices'))
      ->set('notice_killer_prevent_syslog_notices', $form_state->getValue('notice_killer_prevent_syslog_notices'))
      ->set('notice_killer_ignore_line_numbers', $form_state->getValue('notice_killer_ignore_line_numbers'))
      ->set('notice_killer_ignore_file_location', $form_state->getValue('notice_killer_ignore_file_location'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
